@@ -1,7 +1,6 @@
-
 /***************************************************************************
  * libmseed.h:
- * 
+ *
  * Interface declarations for the Mini-SEED library (libmseed).
  *
  * This library is free software; you can redistribute it and/or modify
@@ -18,11 +17,10 @@
  * License along with this software.
  * If not, see <https://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2016 Chad Trabant
+ * Copyright (C) 2017 Chad Trabant
  * IRIS Data Management Center
  ***************************************************************************/
 
-
 #ifndef LIBMSEED_H
 #define LIBMSEED_H 1
 
@@ -30,10 +28,95 @@
 extern "C" {
 #endif
 
-#include "lmplatform.h"
+#define LIBMSEED_VERSION "2.19"
+#define LIBMSEED_RELEASE "2017.053"
 
-#define LIBMSEED_VERSION "2.18"
-#define LIBMSEED_RELEASE "2016.286"
+/* C99 standard headers */
+#include <stdlib.h>
+#include <stdio.h>
+#include <stdarg.h>
+#include <time.h>
+#include <string.h>
+#include <ctype.h>
+
+/* This library uses structs that map to SEED header/blockette
+   structures that are required to have a layout exactly as specified,
+   i.e. no padding.
+
+   If "ATTRIBUTE_PACKED" is defined at compile time (e.g. -DATTRIBUTE_PACKED)
+   the preprocessor will use the define below to add the "packed" attribute
+   to effected structs.  This attribute is supported by GCC and increasingly
+   more compilers.
+  */
+#if defined(ATTRIBUTE_PACKED)
+  #define LMP_PACKED __attribute__((packed))
+#else
+  #define LMP_PACKED
+#endif
+
+/* Set platform specific defines */
+#if defined(__linux__) || defined(__linux) || defined(__CYGWIN__)
+  #define LMP_LINUX 1
+  #define LMP_GLIBC2 1 /* Deprecated */
+#elif defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
+  #define LMP_BSD 1
+#elif defined(__sun__) || defined(__sun)
+  #define LMP_SOLARIS 1
+#elif defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64)
+  #define LMP_WIN 1
+  #define LMP_WIN32 1 /* Deprecated */
+#endif
+
+/* Set platform specific features */
+#if defined(LMP_LINUX) || defined(LMP_BSD) || defined(LMP_SOLARIS)
+  #include <unistd.h>
+  #include <inttypes.h>
+#elif defined(LMP_WIN)
+  #include <windows.h>
+  #include <sys/types.h>
+
+  /* For MSVC 2012 and earlier define standard int types, otherwise use inttypes.h */
+  #if defined(_MSC_VER) && _MSC_VER <= 1700
+    typedef signed char int8_t;
+    typedef unsigned char uint8_t;
+    typedef signed short int int16_t;
+    typedef unsigned short int uint16_t;
+    typedef signed int int32_t;
+    typedef unsigned int uint32_t;
+    typedef signed __int64 int64_t;
+    typedef unsigned __int64 uint64_t;
+  #else
+    #include <inttypes.h>
+  #endif
+
+  /* For MSVC define PRId64 and SCNd64 if needed */
+  #if defined(_MSC_VER)
+    #if !defined(PRId64)
+      #define PRId64 "I64d"
+    #endif
+    #if !defined(SCNd64)
+      #define SCNd64 "I64d"
+    #endif
+
+    #define snprintf _snprintf
+    #define vsnprintf _vsnprintf
+    #define strcasecmp _stricmp
+    #define strncasecmp _strnicmp
+    #define strtoull _strtoui64
+    #define strdup _strdup
+    #define fileno _fileno
+  #endif
+
+  /* Extras needed for MinGW */
+  #if defined(__MINGW32__) || defined(__MINGW64__)
+    #include <fcntl.h>
+
+    #define fstat _fstat
+    #define stat _stat
+  #endif
+#else
+  #include <inttypes.h>
+#endif
 
 #define MINRECLEN   128      /* Minimum Mini-SEED record length, 2^7 bytes */
                              /* Note: the SEED specification minimum is 256 */
@@ -85,7 +168,7 @@ extern "C" {
 
 /* Macro to test for sane year and day values, used primarily to
  * determine if byte order swapping is needed.
- * 
+ *
  * Year : between 1900 and 2100
  * Day  : between 1 and 366
  *
@@ -97,7 +180,7 @@ extern "C" {
 /* Macro to test memory for a SEED data record signature by checking
  * SEED data record header values at known byte offsets to determine
  * if the memory contains a valid record.
- * 
+ *
  * Offset = Value
  * [0-5]  = Digits, spaces or NULL, SEED sequence number
  *     6  = Data record quality indicator
@@ -125,7 +208,7 @@ extern "C" {
 /* Macro to test memory for a blank/noise SEED data record signature
  * by checking for a valid SEED sequence number and padding characters
  * to determine if the memory contains a valid blank/noise record.
- * 
+ *
  * Offset = Value
  * [0-5]  = Digits or NULL, SEED sequence number
  * [6-47] = Space character (ASCII 32), remainder of fixed header
@@ -282,7 +365,7 @@ struct blkt_320_s
   char      rolloff[12];
   char      noise_type[8];
 } LMP_PACKED;
-  
+
 /* Blockette 390, Generic Calibration (without header) */
 struct blkt_390_s
 {
@@ -384,14 +467,14 @@ StreamState;
 typedef struct MSRecord_s {
   char           *record;            /* Mini-SEED record */
   int32_t         reclen;            /* Length of Mini-SEED record in bytes */
-  
+
   /* Pointers to SEED data record structures */
   struct fsdh_s      *fsdh;          /* Fixed Section of Data Header */
   BlktLink           *blkts;         /* Root of blockette chain */
   struct blkt_100_s  *Blkt100;       /* Blockette 100, if present */
   struct blkt_1000_s *Blkt1000;      /* Blockette 1000, if present */
   struct blkt_1001_s *Blkt1001;      /* Blockette 1001, if present */
-  
+
   /* Common header fields in accessible form */
   int32_t         sequence_number;   /* SEED record sequence number */
   char            network[11];       /* Network designation, NULL terminated */
@@ -404,12 +487,12 @@ typedef struct MSRecord_s {
   int64_t         samplecnt;         /* Number of samples in record */
   int8_t          encoding;          /* Data encoding format */
   int8_t          byteorder;         /* Original/Final byte order of record */
-  
+
   /* Data sample fields */
   void           *datasamples;       /* Data samples, 'numsamples' of type 'sampletype'*/
   int64_t         numsamples;        /* Number of data samples in datasamples */
   char            sampletype;        /* Sample type code: a, i, f, d */
-  
+
   /* Stream oriented state information */
   StreamState    *ststate;           /* Stream processing state information */
 }
@@ -421,7 +504,7 @@ typedef struct MSTrace_s {
   char            station[11];       /* Station designation, NULL terminated */
   char            location[11];      /* Location designation, NULL terminated */
   char            channel[11];       /* Channel designation, NULL terminated */
-  char            dataquality;       /* Data quality indicator */ 
+  char            dataquality;       /* Data quality indicator */
   char            type;              /* MSTrace type code */
   hptime_t        starttime;         /* Time of first sample */
   hptime_t        endtime;           /* Time of last sample */
@@ -760,6 +843,9 @@ extern void     ms_gswap8a ( void *data8 );
   ms_gswap2 (x.day);    \
   ms_gswap2 (x.fract);
 
+/* Platform portable functions */
+extern off_t lmp_ftello (FILE *stream);
+extern int lmp_fseeko (FILE *stream, off_t offset, int whence);
 
 #ifdef __cplusplus
 }
